@@ -26,9 +26,9 @@ apt-get -y install wget
 # Download TOMOYO Linux patches.
 mkdir -p /usr/src/rpm/SOURCES/
 cd /usr/src/rpm/SOURCES/ || die "Can't chdir to /usr/src/rpm/SOURCES/ ."
-if [ ! -r ccs-patch-1.8.3-20120120.tar.gz ]
+if [ ! -r ccs-patch-1.8.3-20120505.tar.gz ]
 then
-    wget -O ccs-patch-1.8.3-20120120.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20120120.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.3-20120505.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20120505.tar.gz' || die "Can't download patch."
 fi
 
 # Install kernel source packages.
@@ -40,7 +40,7 @@ tar -jxf linux-source-2.6.26.tar.bz2
 
 # Apply patches and create kernel config.
 cd linux-source-2.6.26 || die "Can't chdir to linux-source-2.6.18/ ."
-tar -zxf /usr/src/rpm/SOURCES/ccs-patch-1.8.3-20120120.tar.gz || die "Can't extract patch."
+tar -zxf /usr/src/rpm/SOURCES/ccs-patch-1.8.3-20120505.tar.gz || die "Can't extract patch."
 patch -p1 < patches/ccs-patch-2.6.26-debian-lenny.diff || die "Can't apply patch."
 cat /boot/config-2.6.26-2-686 config.ccs > .config || die "Can't create config."
 
@@ -48,7 +48,7 @@ cat /boot/config-2.6.26-2-686 config.ccs > .config || die "Can't create config."
 make-kpkg --append-to-version -2-686-ccs --revision `sed -e 's/ /-/' version.Debian` --initrd binary-arch || die "Failed to build kernel package."
 
 # Generate meta packages.
-wget http://ftp.jp.debian.org/debian/pool/main/l/linux-latest-2.6/linux-image-2.6-686_2.6.26+17+lenny1_i386.deb
+wget http://archive.debian.org/debian/pool/main/l/linux-latest-2.6/linux-image-2.6-686_2.6.26+17+lenny1_i386.deb
 generate_meta_package linux-image-2.6-686_2.6.26+17+lenny1_i386.deb linux-image-2.6-686-ccs_2.6.26+17+lenny1_i386.deb
 
 exit 0
