@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is a kernel build script for Fedora 15's 2.6.42 kernel.
+# This is a kernel build script for Fedora 14's 2.6.35 kernel.
 #
 
 die () {
@@ -10,17 +10,17 @@ die () {
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-2.6.42.12-1.fc15.src.rpm ]
+if [ ! -r kernel-2.6.35.14-106.fc14.src.rpm ]
 then
-    wget http://ftp.riken.jp/Linux/fedora/updates/15/SRPMS/kernel-2.6.42.12-1.fc15.src.rpm || die "Can't download source package."
+    wget http://ftp.riken.jp/Linux/fedora/updates/14/SRPMS/kernel-2.6.35.14-106.fc14.src.rpm || die "Can't download source package."
 fi
-rpm --checksig kernel-2.6.42.12-1.fc15.src.rpm || die "Can't verify signature."
-rpm -ivh kernel-2.6.42.12-1.fc15.src.rpm || die "Can't install source package."
+rpm --checksig kernel-2.6.35.14-106.fc14.src.rpm || die "Can't verify signature."
+rpm -ivh kernel-2.6.35.14-106.fc14.src.rpm || die "Can't install source package."
 
 cd /root/rpmbuild/SOURCES/ || die "Can't chdir to /root/rpmbuild/SOURCES/ ."
-if [ ! -r ccs-patch-1.8.3-20120401.tar.gz ]
+if [ ! -r ccs-patch-1.8.3-20120505.tar.gz ]
 then
-    wget -O ccs-patch-1.8.3-20120401.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20120401.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.3-20120505.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20120505.tar.gz' || die "Can't download patch."
 fi
 
 cd /root/rpmbuild/SPECS/ || die "Can't chdir to /root/rpmbuild/SPECS/ ."
@@ -28,16 +28,16 @@ cp -p kernel.spec ccs-kernel.spec || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
 --- ccs-kernel.spec
 +++ ccs-kernel.spec
-@@ -18,7 +18,7 @@
+@@ -23,7 +23,7 @@
  #
  # (Uncomment the '#' and both spaces below to set the buildid.)
  #
 -# % define buildid .local
-+%define buildid _tomoyo_1.8.3p6
++%define buildid _tomoyo_1.8.3p7
  ###################################################################
  
  # The buildid can also be specified on the rpmbuild command line
-@@ -405,6 +405,11 @@
+@@ -424,6 +424,11 @@
  # to versions below the minimum
  #
  
@@ -49,7 +49,7 @@ patch << "EOF" || die "Can't patch spec file."
  #
  # First the general kernel 2.6 required versions as per
  # Documentation/Changes
-@@ -464,7 +469,7 @@
+@@ -483,7 +488,7 @@
  AutoProv: yes\
  %{nil}
  
@@ -58,7 +58,7 @@ patch << "EOF" || die "Can't patch spec file."
  Group: System Environment/Kernel
  License: GPLv2
  URL: http://www.kernel.org/
-@@ -851,7 +856,7 @@
+@@ -1027,7 +1032,7 @@
  AutoReqProv: no\
  Requires(pre): /usr/bin/find\
  Requires: perl\
@@ -67,36 +67,27 @@ patch << "EOF" || die "Can't patch spec file."
  This package provides kernel headers and makefiles sufficient to build modules\
  against the %{?2:%{2} }kernel package.\
  %{nil}
-@@ -1357,6 +1362,10 @@
+@@ -1746,6 +1751,10 @@
  
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.8.3-20120401.tar.gz
-+patch -sp1 < patches/ccs-patch-2.6.42-fedora-15.diff
++tar -zxf %_sourcedir/ccs-patch-1.8.3-20120505.tar.gz
++patch -sp1 < patches/ccs-patch-2.6.35-fedora-14.diff
 +
  %endif
  
  # Any further pre-build tree manipulations happen here.
-@@ -1385,6 +1394,18 @@
+@@ -1774,6 +1783,9 @@
  for i in *.config
  do
    mv $i .config
-+  # TOMOYO Linux 2.5
-+  sed -i -e 's/# CONFIG_SECURITY_PATH is not set/CONFIG_SECURITY_PATH=y/' -- .config
-+  sed -i -e 's/# CONFIG_SECURITY_TOMOYO is not set/CONFIG_SECURITY_TOMOYO=y/' -- .config
-+  echo 'CONFIG_SECURITY_TOMOYO_MAX_ACCEPT_ENTRY=2048' >> .config
-+  echo 'CONFIG_SECURITY_TOMOYO_MAX_AUDIT_LOG=1024' >> .config
-+  echo '# CONFIG_SECURITY_TOMOYO_OMIT_USERSPACE_LOADER is not set' >> .config
-+  echo 'CONFIG_SECURITY_TOMOYO_POLICY_LOADER="/sbin/tomoyo-init"' >> .config
-+  echo 'CONFIG_SECURITY_TOMOYO_ACTIVATION_TRIGGER="/sbin/init"' >> .config
-+  echo '# CONFIG_DEFAULT_SECURITY_TOMOYO is not set' >> .config
-+  # TOMOYO Linux 1.8
++  # TOMOYO Linux
 +  cat config.ccs >> .config
 +  sed -i -e 's:CONFIG_DEBUG_INFO=.*:# CONFIG_DEBUG_INFO is not set:' -- .config
    Arch=`head -1 .config | cut -b 3-`
-   make ARCH=$Arch listnewconfig | grep -E '^CONFIG_' >.newoptions || true
- %if %{listnewconfig_fail}
+   make ARCH=$Arch %{oldconfig_target} > /dev/null
+   echo "# $Arch" > configs/$i
 EOF
 echo ""
 echo ""
@@ -106,7 +97,7 @@ echo "rpmbuild -bb /root/rpmbuild/SPECS/ccs-kernel.spec"
 echo "to build kernel rpm packages."
 echo ""
 ARCH=`uname -m`
-echo "I'll start 'rpmbuild -bb --target $ARCH --without debug --without debuginfo /root/rpmbuild/SPECS/ccs-kernel.spec' in 30 seconds. Press Ctrl-C to stop."
+echo "I'll start 'rpmbuild -bb --target $ARCH --with baseonly --without debug --without debuginfo /root/rpmbuild/SPECS/ccs-kernel.spec' in 30 seconds. Press Ctrl-C to stop."
 sleep 30
-exec rpmbuild -bb --target $ARCH --without debug --without debuginfo /root/rpmbuild/SPECS/ccs-kernel.spec
+exec rpmbuild -bb --target $ARCH --with baseonly --without debug --without debuginfo /root/rpmbuild/SPECS/ccs-kernel.spec
 exit 0
