@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is kernel build script for ubuntu 10.04's 2.6.32 kernel.
+# This is kernel build script for ubuntu 10.10's 2.6.35 kernel.
 #
 
 die () {
@@ -19,22 +19,22 @@ apt-get -y install wget
 # Download TOMOYO Linux patches.
 mkdir -p /root/rpmbuild/SOURCES/
 cd /root/rpmbuild/SOURCES/ || die "Can't chdir to /root/rpmbuild/SOURCES/ ."
-if [ ! -r ccs-patch-1.8.3-20120301.tar.gz ]
+if [ ! -r ccs-patch-1.8.3-20120505.tar.gz ]
 then
-    wget -O ccs-patch-1.8.3-20120301.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20120301.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.3-20120505.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20120505.tar.gz' || die "Can't download patch."
 fi
 
 # Install kernel source packages.
 cd /usr/src/ || die "Can't chdir to /usr/src/ ."
 apt-get -y install fakeroot build-essential || die "Can't install packages."
 apt-get build-dep linux || die "Can't install packages."
-apt-get source linux-source-2.6.32 || die "Can't install kernel source."
-for i in `awk ' { if ( $1 != "Build-Depends:") next; $1 = ""; n = split($0, a, ","); for (i = 1; i <= n; i++) { split(a[i], b, " "); print b[1]; } } ' linux-2.6.32/debian/control`; do apt-get -y install $i; done
+apt-get source linux-source-2.6.35 || die "Can't install kernel source."
+for i in `awk ' { if ( $1 != "Build-Depends:") next; $1 = ""; n = split($0, a, ","); for (i = 1; i <= n; i++) { split(a[i], b, " "); print b[1]; } } ' linux-2.6.35/debian/control`; do apt-get -y install $i; done
 
 # Apply patches and create kernel config.
-cd linux-2.6.32/ || die "Can't chdir to linux-2.6.32/ ."
-tar -zxf /root/rpmbuild/SOURCES/ccs-patch-1.8.3-20120301.tar.gz || die "Can't extract patch."
-patch -p1 < patches/ccs-patch-2.6.32-ubuntu-10.04.diff || die "Can't apply patch."
+cd linux-2.6.35/ || die "Can't chdir to linux-2.6.35/ ."
+tar -zxf /root/rpmbuild/SOURCES/ccs-patch-1.8.3-20120505.tar.gz || die "Can't extract patch."
+patch -p1 < patches/ccs-patch-2.6.35-ubuntu-10.10.diff || die "Can't apply patch."
 rm -fR patches/ specs/ || die "Can't delete patch."
 for i in `find debian.master/ -type f -name '*'${ORIGINAL_FLAVOUR}'*'`; do cp -p $i `echo $i | sed -e 's/'${ORIGINAL_FLAVOUR}'/'${NEW_FLAVOUR}'/g'`; done
 for i in debian.master/config/*/config.common.*; do cat config.ccs >> $i; done
@@ -47,7 +47,7 @@ debian/rules debian/control || die "Can't update control."
 patch -p0 << "EOF" || die "Can't patch link-headers."
 --- debian/scripts/link-headers
 +++ debian/scripts/link-headers
-@@ -39,4 +39,17 @@
+@@ -39,4 +39,19 @@
  done
  )
  
@@ -59,8 +59,10 @@ patch -p0 << "EOF" || die "Can't patch link-headers."
 +	rm -f $hdrdir/include/linux/$i
 +	cp -p $i $hdrdir/include/linux/$i
 +    done
-+    rm -f $hdrdir/security
-+    cd ../../
++    rm -f $hdrdir/include/net $hdrdir/security
++    cd ../
++    tar -cf - net | tar -xf - -C $hdrdir/include/
++    cd ../
 +    tar -cf - security | tar -xf - -C $hdrdir
 +fi
 +
